*______________________________________________________________________________;
*                                                                              ;
* !HZEXAMPLES/bs.death.AVC.summary                                             ;
*                                                                              ;
* Multivariable analysis of death after repair                                 ;
* Bootstrap method                                                             ;
*
* Summary of results
*______________________________________________________________________________;
*                                                                              ;
* Bring in data sets                                                           ;
  LIBNAME EXAMPLES ('!HZEXAMPLES/sasest');
  DATA BSEARLY; SET EXAMPLES.BSAVCE;
  DATA BSCONST; SET EXAMPLES.BSAVCC;
  DATA BSLATE; SET EXAMPLES.BSAVCL;
  TITLE1 "Repair of Atrioventricular Septal (A-V Canal) Defects";
  TITLE2 "Example Data Set";
  TITLE3 "Bootstrap Multivariable Analysis of Death After Repair";
  TITLE4 "Summary of Results";
*______________________________________________________________________________;
*                                                                              ;
*                 S U M M A R Y   S T A T I S T I C S
*______________________________________________________________________________;
*                                                                              ;
* Early phase                                                                  ;
  TITLE7 "Early Phase Models";
* Number of variables in this model phase                                      ;
  DATA BSEARLY; SET BSEARLY NOBS=NUM; _NOBS_=NUM;
  NMODEL=N(OF AGE--ORIFICE, MAL--INC_SURG);
* One time only, determine how many models are available                       ;
  IF _N_=1 THEN CALL SYMPUT('DS_SIZE', _NOBS_); RUN;
* Means, outputting min max mean n as 5 observations                           ;
  PROC UNIVARIATE FREQ; VAR NMODEL;
  PROC MEANS NOPRINT DATA=BSEARLY; OUTPUT OUT=MEANE;
* Transpose data set                                                           ;
  DATA MEANE; SET MEANE; DROP _TYPE_ _FREQ_ RESAMPL _NOBS_;
  PROC TRANSPOSE DATA=MEANE OUT=TMEANE; ID _STAT_;
* Order in descending frequency of occurance                                   ;
  PROC SORT DATA=TMEANE; BY DESCENDING N;
* Summary statistics, since PROC MEANS cannot reorder.                         ;
  DATA TMEANE; SET TMEANE;
    PCTMODEL=100*N/&DS_SIZE;
    T_SCORE=.; DF=.; PRT=.;
    IF N>1 THEN DO;
      IF STD>0 THEN T_SCORE=MEAN/STD;
      DF=N-1;
      IF ABS(T_SCORE)>0 THEN DO;
        PRT=2*(1 - PROBT(ABS(T_SCORE),DF));
        IF PRT<.00001 THEN PRT=.00001;
      END;
    END;
  PROC PRINT DATA=TMEANE;
       VAR _NAME_ N PCTMODEL MIN MAX MEAN STD T_SCORE PRT;
  RUN;

*******************************************************************************;
* Constant phase                                                                  ;
  TITLE7 "Constant Phase Models";
* Number of variables in this model phase                                      ;
  DATA BSCONST; SET BSCONST NOBS=NUM; _NOBS_=NUM;
  NMODEL=N(OF AGE--ORIFICE, MAL--INC_SURG);
* One time only, determine how many models are available                       ;
  IF _N_=1 THEN CALL SYMPUT('DS_SIZE', _NOBS_); RUN;
* Means, outputting min max mean n as 5 observations                           ;
  PROC UNIVARIATE FREQ; VAR NMODEL;
  PROC MEANS NOPRINT DATA=BSCONST; OUTPUT OUT=MEANC;
* Transpose data set                                                           ;
  DATA MEANC; SET MEANC; DROP _TYPE_ _FREQ_ RESAMPL _NOBS_;
  PROC TRANSPOSE DATA=MEANC OUT=TMEANC; ID _STAT_;
* Order in descending frequency of occurance                                   ;
  PROC SORT DATA=TMEANC; BY DESCENDING N;
* Summary statistics, since PROC MEANS cannot reorder.                         ;
  DATA TMEANC; SET TMEANC;
    PCTMODEL=100*N/&DS_SIZE;
    T_SCORE=.; DF=.; PRT=.;
    IF N>1 THEN DO;
      IF STD>0 THEN T_SCORE=MEAN/STD;
      DF=N-1;
      IF ABS(T_SCORE)>0 THEN DO;
        PRT=2*(1 - PROBT(ABS(T_SCORE),DF));
        IF PRT<.00001 THEN PRT=.00001;
      END;
    END;
  PROC PRINT DATA=TMEANC;
       VAR _NAME_ N PCTMODEL MIN MAX MEAN STD T_SCORE PRT;
  RUN;
*******************************************************************************;
* Late phase                                                                   ;
  TITLE7 "Late Phase Models";
* Number of variables in this model phase                                      ;
  DATA BSLATE; SET BSLATE;
  NMODEL=N(OF AGE--ORIFICE, MAL--INC_SURG);
  PROC UNIVARIATE FREQ; VAR NMODEL;
  PROC MEANS NOPRINT DATA=BSLATE; OUTPUT OUT=MEANL;
  DATA MEANL; SET MEANL; DROP _TYPE_ _FREQ_ RESAMPL;
  PROC TRANSPOSE DATA=MEANL OUT=TMEANL; ID _STAT_;
* Order in descending frequency of occurance                                   ;
  PROC SORT DATA=TMEANL; BY DESCENDING N;
* Statistics                                                                   ;
  DATA TMEANL; SET TMEANL;
    PCTMODEL=100*N/&DS_SIZE;
    T_SCORE=.; DF=.; PRT=.;
    IF N>1 THEN DO;
      IF STD>0 THEN T_SCORE=MEAN/STD;
      DF=N-1;
      IF ABS(T_SCORE)>0 THEN DO;
        PRT=2*(1 - PROBT(ABS(T_SCORE),DF));
        IF PRT<.00001 THEN PRT=.00001;
      END;
    END;
  PROC PRINT DATA=TMEANL;
       VAR _NAME_ N PCTMODEL MIN MAX MEAN STD T_SCORE PRT;
  RUN;
*******************************************************************************;
